#
#--
# ScanDB - A library for importing and analyzing information generated by
# various network scanning utilities.
#
# Copyright (c) 2008 Hal Brodigan (postmodern.mod3 at gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#++
#

require 'scandb/model'
require 'scandb/service'
require 'scandb/port'
require 'scandb/host'

module ScanDB
  class ScannedPort

    include Model

    # The scan status of the Port (<tt>:open</tt>, <tt>:filtered</tt>,
    # <tt>:closed</tt>)
    property :status, Enum[:open, :filtered, :closed]

    # The Date and Time at which the port was first scanned
    property :scanned_at, DateTime

    # The Service that is running on the scanned port
    belongs_to :service

    # The Port
    belongs_to :port

    # The Host that the scan was performed against
    belongs_to :host

    #
    # Returns the String form of the scanned port.
    #
    def to_s
      sprintf("%9s%9s\t%s",port,status,service)
    end

  end
end
